import * as i0 from '@angular/core';
import { Injectable, Component, Input, EventEmitter, Output, ViewEncapsulation, NgModule } from '@angular/core';
import * as i2$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { BehaviorSubject } from 'rxjs';
import * as Ably from 'ably';
import Swal from 'sweetalert2';
import * as i1 from '@angular/platform-browser';
import * as i2 from '@angular/common/http';
import { HttpClientModule } from '@angular/common/http';
import moment from 'moment';

class NotificationService {
    constructor(titleService, http) {
        this.titleService = titleService;
        this.http = http;
        this.isOpen = new BehaviorSubject(false);
        this.currentisOpen = this.isOpen.asObservable();
        this.count = new BehaviorSubject(0);
        this.currentCount = this.count.asObservable();
        this.API_BASE_URL = 'https://api.ravenapp.dev';
        this.notifications = new BehaviorSubject([]);
        this.currentNotifications = this.notifications.asObservable();
        this.unread = new BehaviorSubject(0);
        this.currentUnread = this.unread.asObservable();
    }
    // tslint:disable: typedef
    READ_ALL(appId) {
        return (this.API_BASE_URL + `/v1/apps/${appId}/in_app_notifications/read_all`);
    }
    FETCH(appId) {
        return this.API_BASE_URL + `/v1/apps/${appId}/in_app_notifications/fetch`;
    }
    UPDATE(appId) {
        return this.API_BASE_URL + `/v1/apps/${appId}/in_app_notifications/update`;
    }
    FETCH_COUNT(appId, userId) {
        return (this.API_BASE_URL +
            `/v1/apps/${appId}/in_app_notifications/unread_count?user_id=${userId}`);
    }
    LAST_SEEN(appId, userId) {
        return (this.API_BASE_URL +
            `/v1/apps/${appId}/in_app_notifications/last_open?user_id=${userId}`);
    }
    DELIVERY_UPDATE(appId) {
        return this.API_BASE_URL + `/v1/apps/${appId}/in_app/status`;
    }
    ABLY_TOKEN(appId, userId, signature) {
        return (this.API_BASE_URL +
            `/v1/apps/${appId}/in_app_notifications/ably_token?user_id=${userId}&user_signature=${signature}`);
    }
    USER_SETUP(appId, userId, signature) {
        return (this.API_BASE_URL +
            `/v1/apps/${appId}/in_app_notifications/setup?user_id=${userId}`);
    }
    setSelectedNotification(notification) {
        this.selectedNotification = notification;
    }
    userSetup() {
        return this.http.post(this.USER_SETUP(this.appId, this.userId, this.signature), {}, {
            headers: {
                'X-Raven-User-Signature': this.signature,
            },
        });
    }
    fetchCount() {
        return this.http.get(this.FETCH_COUNT(this.appId, this.userId));
    }
    updateLastSeen() {
        return this.http.put(this.LAST_SEEN(this.appId, this.userId), {});
    }
    fetchNotifications(lastMessageId) {
        return this.http.post(this.FETCH(this.appId), {
            user_id: this.userId,
            last_message_id: lastMessageId,
        }, {
            headers: {
                'X-Raven-User-Signature': this.signature,
            },
        });
    }
    updateNotification(status, messageId) {
        return this.http.put(this.UPDATE(this.appId), {
            user_id: this.userId,
            message_id: messageId,
            status,
        }, {
            headers: {
                'X-Raven-User-Signature': this.signature,
            },
        });
    }
    markAllRead() {
        this.http
            .put(this.READ_ALL(this.appId), {
            user_id: this.userId,
            message_id: this.notifications.value[0].message_id,
        }, {
            headers: {
                'X-Raven-User-Signature': this.signature,
            },
        })
            .subscribe({
            next: (res) => {
                this.notifications.next(this.notifications.value.map((notification) => {
                    return { ...notification, status: 'READ' };
                }));
                this.updateUnread(0);
            },
        });
    }
    reloadData() {
        this.fetchNotifications(null).subscribe({
            next: (res) => {
                this.updateNotifications(res.notifications);
                // this.showLoadButton = !(res.notifications.length < 20);
                this.updateUnread(0);
                let tempUnread = 0;
                res.notifications.map((notification) => {
                    if (notification.status === 'UNREAD') {
                        tempUnread += 1;
                    }
                });
                this.updateUnread(tempUnread);
            },
            error: (err) => console.log(err),
        });
    }
    deliveryStatusUpdate(messageId, date) {
        return this.http.post(this.DELIVERY_UPDATE(this.appId), {
            timestamp: date - 1000,
            status: 'DELIVERED',
            notification_id: messageId,
            current_timestamp: date - 1000,
        });
    }
    toggleModal(value) {
        if (value) {
            this.updateCount(0);
            if (this.appId && this.userId) {
                this.updateLastSeen().subscribe();
            }
        }
        this.isOpen.next(value);
    }
    updateCount(count) {
        this.count.next(count);
        this.setTitle(count);
    }
    updateNotifications(notifications) {
        this.notifications.next(notifications);
    }
    updateUnread(unread) {
        this.unread.next(unread);
    }
    setTitle(count) {
        const tmp = this.titleService.getTitle().indexOf(') ');
        if (count > 0) {
            this.titleService.setTitle(`(${count}) ${this.titleService.getTitle().substring(tmp + 1)}`);
        }
        if (tmp !== -1 && count === 0) {
            this.titleService.setTitle(this.titleService.getTitle().substring(tmp + 1));
        }
    }
    deintialize() {
        if (this.channel) {
            this.channel.detach();
        }
    }
    intialize(appId, userId, signature) {
        this.userId = userId;
        this.appId = appId;
        this.signature = signature;
        this.userSetup().subscribe({
            next: () => {
                this.fetchCount().subscribe({
                    next: (res) => {
                        this.updateCount(res.unread_count);
                    },
                });
                this.client = new Ably.Realtime({
                    authUrl: this.ABLY_TOKEN(appId, userId, signature),
                });
                /* inferred type Ably.Realtime */
                const channelName = appId + '-' + userId;
                this.channel =
                    this.client.channels.get(channelName); /* inferred type Ably.Types.RealtimeChannel */
                this.channel.subscribe((message) => {
                    if (!this.isOpen.value) {
                        this.updateCount(this.count.value + 1);
                    }
                    this.updateUnread(this.unread.value);
                    setTimeout(() => {
                        this.deliveryStatusUpdate(message.data.raven_notification_id, new Date().getTime()).subscribe();
                    }, 1000);
                    const temp = {
                        message_id: message.data.raven_notification_id,
                        message_body: {
                            title: message.data.title,
                            body: message.data.body,
                            click_action: message.data.click_action,
                            data: message.data.data,
                        },
                        timestamp: message.data.timestamp,
                        status: 'UNREAD',
                    };
                    this.updateNotifications([temp].concat(this.notifications.value));
                    Swal.fire({
                        title: message.data.title,
                        text: message.data.body,
                        icon: 'success',
                        toast: true,
                        position: 'top-end',
                        timerProgressBar: true,
                        showConfirmButton: false,
                        showCloseButton: true,
                        timer: 8000,
                        didOpen: (toast) => {
                            toast.addEventListener('mouseenter', Swal.stopTimer);
                            toast.addEventListener('mouseleave', Swal.resumeTimer);
                        },
                    }).then((result) => {
                        if (result.isDismissed && result.dismiss?.toString() === 'close') {
                            this.updateCount(this.count.value - 1);
                        }
                    });
                });
            },
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationService, deps: [{ token: i1.Title }, { token: i2.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: i1.Title }, { type: i2.HttpClient }]; } });

class BellIconComponent {
    constructor(notificationService) {
        this.notificationService = notificationService;
        this.indicatorType = 'count';
        this.solidBellIcon = 'fa-solid fa-bell';
        this.regularBellIcon = 'fa-regular fa-bell';
    }
    ngOnInit() {
        this.subscription = this.notificationService.currentisOpen.subscribe((isOpen) => {
            this.isOpen = isOpen;
        });
        this.countSubscription = this.notificationService.currentCount.subscribe((count) => (this.count = count));
        this.fetchCountSubscription = this.notificationService
            .fetchCount()
            .subscribe({
            next: (res) => {
                this.count = res.unread_count;
                this.notificationService.updateCount(res.unread_count);
            },
        });
    }
    // tslint:disable: typedef
    toggleModal() {
        this.notificationService.toggleModal(!this.isOpen);
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
        this.countSubscription.unsubscribe();
        this.fetchCountSubscription.unsubscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BellIconComponent, deps: [{ token: NotificationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: BellIconComponent, selector: "app-bell-icon", inputs: { color: "color", indicatorType: "indicatorType" }, ngImport: i0, template: "<button\n  (click)=\"toggleModal()\"\n  class=\"notification-btn\"\n  [ngStyle]=\"{ color: color ? color : 'blue' }\"\n>\n  <i [ngClass]=\"[!isOpen ? regularBellIcon : solidBellIcon]\"></i>\n  <span\n    *ngIf=\"!isOpen && count > 0 && indicatorType === 'count'\"\n    class=\"count\"\n    >{{ count }}</span\n  >\n  <span\n    *ngIf=\"!isOpen && count > 0 && indicatorType === 'dot'\"\n    class=\"fas fa-circle dot\"\n  ></span>\n</button>\n", styles: [".notification-btn{display:flex;align-items:center;justify-content:center;background:transparent;position:relative;border:none;font-size:1.5rem;cursor:pointer;height:2.3rem;width:2.3rem}.notification-btn:hover{background-color:#f1f1f1;border-radius:1.15rem}.count{display:flex;align-items:center;justify-content:center;height:.6rem;width:.6rem;position:absolute;font-size:.6rem;top:0;background-color:red;color:#fff;border-radius:.5rem;padding:.2rem;margin-left:1.2rem;margin-top:-.3rem}.dot{position:absolute;top:0;color:red;font-size:.6rem;border-radius:.5rem;margin-left:1.2rem}\n"], dependencies: [{ kind: "directive", type: i2$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BellIconComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-bell-icon', template: "<button\n  (click)=\"toggleModal()\"\n  class=\"notification-btn\"\n  [ngStyle]=\"{ color: color ? color : 'blue' }\"\n>\n  <i [ngClass]=\"[!isOpen ? regularBellIcon : solidBellIcon]\"></i>\n  <span\n    *ngIf=\"!isOpen && count > 0 && indicatorType === 'count'\"\n    class=\"count\"\n    >{{ count }}</span\n  >\n  <span\n    *ngIf=\"!isOpen && count > 0 && indicatorType === 'dot'\"\n    class=\"fas fa-circle dot\"\n  ></span>\n</button>\n", styles: [".notification-btn{display:flex;align-items:center;justify-content:center;background:transparent;position:relative;border:none;font-size:1.5rem;cursor:pointer;height:2.3rem;width:2.3rem}.notification-btn:hover{background-color:#f1f1f1;border-radius:1.15rem}.count{display:flex;align-items:center;justify-content:center;height:.6rem;width:.6rem;position:absolute;font-size:.6rem;top:0;background-color:red;color:#fff;border-radius:.5rem;padding:.2rem;margin-left:1.2rem;margin-top:-.3rem}.dot{position:absolute;top:0;color:red;font-size:.6rem;border-radius:.5rem;margin-left:1.2rem}\n"] }]
        }], ctorParameters: function () { return [{ type: NotificationService }]; }, propDecorators: { color: [{
                type: Input
            }], indicatorType: [{
                type: Input
            }] } });

class NotificationComponent {
    constructor(notificationService) {
        this.notificationService = notificationService;
        this.unreadEmitter = new EventEmitter();
        this.isDeleteDialogOpen = false;
        this.isOpen = false;
    }
    ngOnInit() { }
    // tslint:disable-next-line: typedef
    toggleActions(e) {
        e.stopPropagation();
        this.notificationService.setSelectedNotification(this.notification);
        if (!this.isOpen) {
            if (this.notificationService.selectedNotification === null) {
                this.isOpen = true;
                return;
            }
            if (this.notificationService.selectedNotification) {
                this.isOpen =
                    this.notification.message_id ===
                        this.notificationService.selectedNotification.message_id;
            }
        }
        else {
            this.isOpen = false;
        }
    }
    // tslint:disable-next-line: typedef
    closeModal() {
        this.isOpen = false;
    }
    // tslint:disable-next-line: typedef
    onNoticationClick(event, callbackObj) {
        if (event.target.className !== 'action') {
            if (this.notification.status === 'UNREAD') {
                this.updateNotificationUtil('READ', this.notification.message_id);
            }
            this.onClickNotification(callbackObj);
        }
    }
    checkCurrentNotification() {
        if (this.notificationService.selectedNotification === null) {
            return true;
        }
        return (this.notification.message_id ===
            this.notificationService.selectedNotification.message_id);
    }
    // tslint:disable-next-line: typedef
    getDateTimeString(dateValue) {
        const date = new Date(parseInt(dateValue, 10));
        return moment(date).format('DD-MM-YYYY hh:mm:ss a');
    }
    // tslint:disable-next-line: typedef
    updateNotification(status, messageId) {
        if (status === 'ARCHIVE') {
            this.isDeleteDialogOpen = true;
        }
        else {
            this.updateNotificationUtil(status, messageId);
        }
    }
    // tslint:disable-next-line: typedef
    hideNotification() {
        this.updateNotificationUtil('ARCHIVE', this.notification.message_id);
    }
    // tslint:disable-next-line: typedef
    closeDeleteDialog() {
        this.isDeleteDialogOpen = false;
    }
    // tslint:disable-next-line: typedef
    closeDeleteDialogOutside(event) {
        if (event.target.className === 'modal-background' &&
            this.isDeleteDialogOpen) {
            this.closeDeleteDialog();
        }
    }
    // tslint:disable-next-line: typedef
    updateNotificationUtil(status, messageId) {
        this.notificationService.updateNotification(status, messageId).subscribe({
            next: (res) => {
                this.unreadEmitter.emit({
                    status,
                    message_id: this.notification.message_id,
                    current_status: this.notification.status,
                });
                this.notification.status = status;
            },
            error: (err) => console.log(err),
        });
    }
    // tslint:disable-next-line: typedef
    timeDiff(dateValue) {
        const date = moment(new Date(parseInt(dateValue, 10)));
        const currentDate = moment(new Date());
        const timeDiffSeconds = currentDate.diff(date, 'seconds');
        const timeDiffMinutes = currentDate.diff(date, 'minutes');
        const timeDiffHours = currentDate.diff(date, 'hours');
        const timeDiffDays = currentDate.diff(date, 'days');
        const timeDiffWeeks = currentDate.diff(date, 'weeks');
        const timeDiffMonths = currentDate.diff(date, 'months');
        const timeDiffYears = currentDate.diff(date, 'years');
        if (timeDiffYears > 0) {
            return timeDiffYears + 'y';
        }
        if (timeDiffMonths > 0) {
            return timeDiffMonths + 'mo';
        }
        if (timeDiffWeeks > 0) {
            return timeDiffWeeks + 'w';
        }
        if (timeDiffDays > 0) {
            return timeDiffDays + 'd';
        }
        if (timeDiffHours > 0) {
            return timeDiffHours + 'h';
        }
        if (timeDiffMinutes > 0) {
            return timeDiffMinutes + 'm';
        }
        if (timeDiffSeconds > 0) {
            return timeDiffSeconds + 's';
        }
        return;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationComponent, deps: [{ token: NotificationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: NotificationComponent, selector: "app-notification", inputs: { notification: "notification", color: "color", onClickNotification: "onClickNotification" }, outputs: { unreadEmitter: "unreadEmitter" }, host: { listeners: { "window:click": "closeModal()" } }, ngImport: i0, template: "<div\n  class=\"notification\"\n  (click)=\"\n    onClickNotification\n      ? onNoticationClick($event, {\n          click_action: notification.message_body.click_action,\n          data: notification.message_body.data\n        })\n      : null\n  \"\n>\n  <div class=\"notification-detail\">\n    <div>\n      <span\n        class=\"fas fa-circle\"\n        *ngIf=\"notification.status === 'UNREAD'\"\n        [ngStyle]=\"{ color: color ? color : 'blue' }\"\n      ></span>\n    </div>\n    <div class=\"notification-container\">\n      <div class=\"notification-title\">\n        <p>{{ notification.message_body.title }}</p>\n        <div class=\"actions-main\">\n          <button\n            class=\"btn\"\n            (click)=\"toggleActions($event)\"\n            [ngStyle]=\"{ color: 'rgb(104, 101, 101)' }\"\n          >\n            <i class=\"fas fa-ellipsis-v\"></i>\n          </button>\n          <div class=\"actions\" *ngIf=\"isOpen && checkCurrentNotification()\">\n            <div\n              class=\"action\"\n              (click)=\"updateNotification('READ', notification.message_id)\"\n              *ngIf=\"notification.status !== 'READ'\"\n            >\n              <i class=\"fas fa-check-double\"></i>\n              Mark as read\n            </div>\n            <div\n              class=\"action\"\n              (click)=\"updateNotification('UNREAD', notification.message_id)\"\n              *ngIf=\"notification.status !== 'UNREAD'\"\n            >\n              <span class=\"fas fa-circle\"></span>Mark as unread\n            </div>\n            <div\n              class=\"action\"\n              (click)=\"updateNotification('ARCHIVE', notification.message_id)\"\n              *ngIf=\"notification.status !== 'ARCHIVE'\"\n            >\n              <i class=\"fas fa-eye-slash\"></i>Hide\n            </div>\n          </div>\n        </div>\n      </div>\n      <div class=\"des-time\">\n        <p class=\"notification-des\">\n          {{ notification.message_body.body }}\n        </p>\n        <div class=\"tooltip\">\n          {{ timeDiff(notification.timestamp) }}\n          <p class=\"tooltiptext\">\n            {{ getDateTimeString(notification.timestamp) }}\n          </p>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n\n<div\n  class=\"modal-background\"\n  *ngIf=\"isDeleteDialogOpen\"\n  (click)=\"closeDeleteDialogOutside($event)\"\n>\n  <div class=\"modal-content\">\n    <h3 style=\"color: black; font-size: 1.5rem; margin-bottom: 1rem\">\n      Hide notification?\n    </h3>\n    <div class=\"dark-divider\"></div>\n    <p style=\"color: rgb(104, 101, 101); font-size: 1rem; margin-top: 1rem\">\n      Hiding will remove the notification from the list. You will be unable to\n      access it later.\n    </p>\n    <div class=\"btn-group\">\n      <button (click)=\"closeDeleteDialog()\" class=\"cancel-btn\">Cancel</button>\n      <button class=\"confirm-btn\" (click)=\"hideNotification()\">Hide</button>\n    </div>\n  </div>\n</div>\n", styles: [".notification{cursor:pointer;padding:.8rem .8rem .8rem .5rem}.notification:hover{background-color:#add8e6}.notification span{font-size:.5rem}.notification-title{display:flex;justify-content:space-between}.notification-detail{display:grid;grid-template-columns:1rem 1fr;align-items:center;margin-right:.3rem;padding:0}.des-time{display:flex;justify-content:space-between;margin-top:.4rem}.notification-des{color:#686565;font-size:.85rem}.name{font-weight:700}.actions-main{position:relative}.actions{position:absolute;width:160px;box-shadow:#0000003d 0 3px 8px;border-radius:.2rem;right:0;background-color:#fafafa;z-index:1}.action{display:flex;align-items:center;padding:.65rem;font-size:.9rem;color:gray}.action:hover{background-color:#f1f1f1}.action i,.action span{width:1rem;margin-right:.5rem}.notification-container{margin-left:.1rem}button{display:flex;align-items:center;justify-content:center;background:transparent;border:none;cursor:pointer;font-size:1rem}.btn{margin-left:.3rem;padding:.5rem;height:2rem;width:2rem;margin-top:-.5rem;margin-right:-.5rem}.btn:hover{background-color:#f1f1f1;border-radius:1rem}.tooltip{position:relative;display:inline-block;color:#686565;font-size:.8rem;margin-left:1rem}.tooltiptext{font-size:.7rem}.tooltip .tooltiptext{visibility:hidden;width:150px;background-color:#676464;color:#fff;text-align:center;border-radius:6px;padding:5px 0;position:absolute;z-index:1;top:24px;left:50%;margin-left:-130px}.tooltip .tooltiptext:after{content:\"\";position:absolute;bottom:100%;left:85%;margin-left:-5px;border-width:5px;border-style:solid;border-color:transparent transparent rgb(113,107,107) transparent}.tooltip:hover .tooltiptext{visibility:visible}.modal-background{position:fixed;top:0;left:0;width:100%;height:100%;background:#0009;z-index:2}.modal-content{box-shadow:#0000001a 0 4px 12px;position:relative;background:#eee7e7;min-width:300px;width:350px;height:auto;top:50%;margin:0 auto;transform:translateY(-50%);border-radius:.5rem;text-align:center;padding:1.5rem;z-index:5}.modal-content h3,.modal-content p{text-align:left}.btn-group{display:flex;justify-content:flex-end;margin-top:2rem}.confirm-btn{color:#fff;background-color:#00f;border-radius:.3rem;padding:.3rem .6rem;margin-left:1rem}.cancel-btn{color:red;border-radius:.3rem;padding:.3rem .6rem}.cancel-btn:hover{background-color:#f1f1f1}.dark-divider{background-color:#cbcbcb;height:1px}@media (max-width: 480px){.modal-content{width:300px}}\n"], dependencies: [{ kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-notification', host: {
                        '(window:click)': 'closeModal()',
                    }, template: "<div\n  class=\"notification\"\n  (click)=\"\n    onClickNotification\n      ? onNoticationClick($event, {\n          click_action: notification.message_body.click_action,\n          data: notification.message_body.data\n        })\n      : null\n  \"\n>\n  <div class=\"notification-detail\">\n    <div>\n      <span\n        class=\"fas fa-circle\"\n        *ngIf=\"notification.status === 'UNREAD'\"\n        [ngStyle]=\"{ color: color ? color : 'blue' }\"\n      ></span>\n    </div>\n    <div class=\"notification-container\">\n      <div class=\"notification-title\">\n        <p>{{ notification.message_body.title }}</p>\n        <div class=\"actions-main\">\n          <button\n            class=\"btn\"\n            (click)=\"toggleActions($event)\"\n            [ngStyle]=\"{ color: 'rgb(104, 101, 101)' }\"\n          >\n            <i class=\"fas fa-ellipsis-v\"></i>\n          </button>\n          <div class=\"actions\" *ngIf=\"isOpen && checkCurrentNotification()\">\n            <div\n              class=\"action\"\n              (click)=\"updateNotification('READ', notification.message_id)\"\n              *ngIf=\"notification.status !== 'READ'\"\n            >\n              <i class=\"fas fa-check-double\"></i>\n              Mark as read\n            </div>\n            <div\n              class=\"action\"\n              (click)=\"updateNotification('UNREAD', notification.message_id)\"\n              *ngIf=\"notification.status !== 'UNREAD'\"\n            >\n              <span class=\"fas fa-circle\"></span>Mark as unread\n            </div>\n            <div\n              class=\"action\"\n              (click)=\"updateNotification('ARCHIVE', notification.message_id)\"\n              *ngIf=\"notification.status !== 'ARCHIVE'\"\n            >\n              <i class=\"fas fa-eye-slash\"></i>Hide\n            </div>\n          </div>\n        </div>\n      </div>\n      <div class=\"des-time\">\n        <p class=\"notification-des\">\n          {{ notification.message_body.body }}\n        </p>\n        <div class=\"tooltip\">\n          {{ timeDiff(notification.timestamp) }}\n          <p class=\"tooltiptext\">\n            {{ getDateTimeString(notification.timestamp) }}\n          </p>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n\n<div\n  class=\"modal-background\"\n  *ngIf=\"isDeleteDialogOpen\"\n  (click)=\"closeDeleteDialogOutside($event)\"\n>\n  <div class=\"modal-content\">\n    <h3 style=\"color: black; font-size: 1.5rem; margin-bottom: 1rem\">\n      Hide notification?\n    </h3>\n    <div class=\"dark-divider\"></div>\n    <p style=\"color: rgb(104, 101, 101); font-size: 1rem; margin-top: 1rem\">\n      Hiding will remove the notification from the list. You will be unable to\n      access it later.\n    </p>\n    <div class=\"btn-group\">\n      <button (click)=\"closeDeleteDialog()\" class=\"cancel-btn\">Cancel</button>\n      <button class=\"confirm-btn\" (click)=\"hideNotification()\">Hide</button>\n    </div>\n  </div>\n</div>\n", styles: [".notification{cursor:pointer;padding:.8rem .8rem .8rem .5rem}.notification:hover{background-color:#add8e6}.notification span{font-size:.5rem}.notification-title{display:flex;justify-content:space-between}.notification-detail{display:grid;grid-template-columns:1rem 1fr;align-items:center;margin-right:.3rem;padding:0}.des-time{display:flex;justify-content:space-between;margin-top:.4rem}.notification-des{color:#686565;font-size:.85rem}.name{font-weight:700}.actions-main{position:relative}.actions{position:absolute;width:160px;box-shadow:#0000003d 0 3px 8px;border-radius:.2rem;right:0;background-color:#fafafa;z-index:1}.action{display:flex;align-items:center;padding:.65rem;font-size:.9rem;color:gray}.action:hover{background-color:#f1f1f1}.action i,.action span{width:1rem;margin-right:.5rem}.notification-container{margin-left:.1rem}button{display:flex;align-items:center;justify-content:center;background:transparent;border:none;cursor:pointer;font-size:1rem}.btn{margin-left:.3rem;padding:.5rem;height:2rem;width:2rem;margin-top:-.5rem;margin-right:-.5rem}.btn:hover{background-color:#f1f1f1;border-radius:1rem}.tooltip{position:relative;display:inline-block;color:#686565;font-size:.8rem;margin-left:1rem}.tooltiptext{font-size:.7rem}.tooltip .tooltiptext{visibility:hidden;width:150px;background-color:#676464;color:#fff;text-align:center;border-radius:6px;padding:5px 0;position:absolute;z-index:1;top:24px;left:50%;margin-left:-130px}.tooltip .tooltiptext:after{content:\"\";position:absolute;bottom:100%;left:85%;margin-left:-5px;border-width:5px;border-style:solid;border-color:transparent transparent rgb(113,107,107) transparent}.tooltip:hover .tooltiptext{visibility:visible}.modal-background{position:fixed;top:0;left:0;width:100%;height:100%;background:#0009;z-index:2}.modal-content{box-shadow:#0000001a 0 4px 12px;position:relative;background:#eee7e7;min-width:300px;width:350px;height:auto;top:50%;margin:0 auto;transform:translateY(-50%);border-radius:.5rem;text-align:center;padding:1.5rem;z-index:5}.modal-content h3,.modal-content p{text-align:left}.btn-group{display:flex;justify-content:flex-end;margin-top:2rem}.confirm-btn{color:#fff;background-color:#00f;border-radius:.3rem;padding:.3rem .6rem;margin-left:1rem}.cancel-btn{color:red;border-radius:.3rem;padding:.3rem .6rem}.cancel-btn:hover{background-color:#f1f1f1}.dark-divider{background-color:#cbcbcb;height:1px}@media (max-width: 480px){.modal-content{width:300px}}\n"] }]
        }], ctorParameters: function () { return [{ type: NotificationService }]; }, propDecorators: { notification: [{
                type: Input
            }], color: [{
                type: Input
            }], unreadEmitter: [{
                type: Output
            }], onClickNotification: [{
                type: Input
            }] } });

class NotificationsComponent {
    constructor(notificationService) {
        this.notificationService = notificationService;
        this.color = 'blue';
        this.indicatorType = 'count';
        this.title = 'in-app-notifications';
        this.notifications = [];
        this.isLoading = false;
        this.newNotifications = false;
        this.showLoadButton = true;
        this.unread = 0;
    }
    ngOnInit() {
        this.subscription = this.notificationService.currentisOpen.subscribe((isOpen) => (this.isOpen = isOpen));
        this.notificationService.currentNotifications.subscribe((notifications) => {
            this.notifications = notifications;
            this.showLoadButton = !(notifications.length < 20);
        });
        this.notificationService.currentUnread.subscribe((unread) => (this.unread = unread));
        this.initialize();
    }
    saveData() {
        this.isLoading = true;
        this.notificationService.reloadData();
        this.isLoading = false;
    }
    onWrapperClick(event) {
        if (event.target.className === 'wrapper' && this.isOpen) {
            this.toggleModal();
        }
    }
    toggleModal() {
        this.notificationService.toggleModal(false);
    }
    markAllRead() {
        this.notificationService.markAllRead();
    }
    updateUnreadCount(event) {
        const status = event.status;
        const message_id = event.message_id;
        const current_status = event.current_status;
        if (status === 'READ' || current_status === 'UNREAD') {
            this.notificationService.updateUnread(this.unread - 1);
        }
        if (status === 'UNREAD') {
            this.notificationService.updateUnread(this.unread + 1);
        }
        if (status === 'ARCHIVE') {
            this.notificationService.updateNotifications(this.notifications.filter((notification) => notification.message_id !== message_id));
        }
    }
    loadMore() {
        this.notificationService
            .fetchNotifications(this.notifications[this.notifications.length - 1].message_id)
            .subscribe({
            next: (res) => {
                this.showLoadButton = !(res.notifications.length < 20);
                this.notificationService.updateNotifications(this.notifications.concat(res.notifications));
                let tempUnread = this.unread;
                res.notifications.map((notification) => {
                    if (notification.status === 'UNREAD') {
                        tempUnread += 1;
                    }
                });
                this.notificationService.updateUnread(tempUnread);
            },
            error: (err) => console.log(err),
        });
    }
    initialize() {
        this.isLoading = true;
        this.fetchSubscription = this.notificationService
            .fetchNotifications(null)
            .subscribe({
            next: (res) => {
                this.notificationService.updateNotifications(res.notifications);
                this.showLoadButton = !(res.notifications.length < 20);
                this.notificationService.updateUnread(0);
                let tempUnread = 0;
                res.notifications.map((notification) => {
                    if (notification.status === 'UNREAD') {
                        tempUnread += 1;
                    }
                });
                this.notificationService.updateUnread(tempUnread);
                this.notificationService.updateCount(0);
                this.isLoading = false;
            },
            error: (err) => console.log(err),
        });
        if (this.displayStyle === 'fullScreen') {
            this.notificationService.updateLastSeen().subscribe();
        }
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
        this.fetchSubscription.unsubscribe();
        if (this.createUserSubscription) {
            this.createUserSubscription.unsubscribe();
        }
        if (this.markAllReadSubcription) {
            this.markAllReadSubcription.unsubscribe();
        }
        if (this.deliveryStatusUpdateSubscription) {
            this.deliveryStatusUpdateSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationsComponent, deps: [{ token: NotificationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: NotificationsComponent, selector: "app-notifications", inputs: { color: "color", indicatorType: "indicatorType", fontStyle: "fontStyle", onClickNotification: "onClickNotification", displayStyle: "displayStyle", position: "position", header: "header" }, ngImport: i0, template: "<div [ngStyle]=\"{\n    fontFamily: fontStyle ? fontStyle : 'inherit',\n    position: displayStyle === 'drawer' ? 'fixed' : 'relative'\n  }\" *ngIf=\"isOpen && displayStyle !== 'fullScreen'\" class=\"wrapper\" (click)=\"onWrapperClick($event)\">\n  <div class=\"notifications\" *ngIf=\"isOpen && displayStyle !== 'fullScreen'\" [ngClass]=\"{\n      bubble: displayStyle === 'bubble',\n      left: displayStyle === 'bubble' && position === 'left',\n      center: displayStyle === 'bubble' && position === 'center',\n      right: displayStyle === 'bubble' && position === 'right',\n      drawerLeft: displayStyle === 'drawer' && position === 'left',\n      drawerRight: displayStyle === 'drawer' && position === 'right'\n    }\">\n    <div class=\"notifications-title\">\n      <div class=\"notifications-header\">\n        <h3 class=\"refresh\" [ngStyle]=\"{ marginBottom: '0.4rem' }\">\n          Notifications\n        </h3>\n        <div class=\"btn-group\">\n          <div class=\"tooltip\">\n            <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"saveData()\">\n              <i class=\"fas fa-redo\"></i>\n            </button>\n            <span class=\"tooltiptext\">Refresh</span>\n          </div>\n          <div class=\"tooltip\">\n            <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"markAllRead()\">\n              <i class=\"fas fa-check-double\"></i>\n            </button>\n            <span class=\"tooltiptext\">Mark all as read</span>\n          </div>\n          <button class=\"btn\" (click)=\"toggleModal()\" [ngStyle]=\"{ color: 'rgb(104, 101, 101)', marginLeft: '1rem' }\">\n            <i class=\"fas fa-times\"></i>\n          </button>\n        </div>\n      </div>\n      <p class=\"date\">\n        {{ unread > 0 ? unread : \"No\" }}\n        unread notifications\n      </p>\n    </div>\n    <div class=\"dark-divider\"></div>\n    <div class=\"all-notifications\" [ngClass]=\"{\n        bubbleHeight: displayStyle === 'bubble',\n        fullHeight: displayStyle === 'drawer'\n      }\" *ngIf=\"!isLoading && notifications.length > 0\" #divToScroll>\n      <div *ngFor=\"let notification of notifications\">\n        <app-notification *ngIf=\"notification\" [notification]=\"notification\" [color]=\"color\"\n          (unreadEmitter)=\"updateUnreadCount($event)\" [onClickNotification]=\"onClickNotification\"></app-notification>\n        <div class=\"divider\"></div>\n      </div>\n      <button [ngStyle]=\"{ color: color ? color : 'blue' }\" *ngIf=\"showLoadButton\" class=\"load-more\"\n        (click)=\"loadMore()\" #loadButton>\n        LOAD MORE\n      </button>\n    </div>\n    <div *ngIf=\"isLoading\" class=\"loading-main\" [ngClass]=\"{\n        bubbleHeight: displayStyle === 'bubble',\n        fullHeight: displayStyle === 'drawer'\n      }\">\n      <div class=\"loading\" [ngStyle]=\"{ borderTopColor: color ? color : 'blue' }\"></div>\n    </div>\n    <div *ngIf=\"!isLoading && notifications.length === 0\" class=\"loading-main\" [ngClass]=\"{\n        bubbleHeight: displayStyle === 'bubble',\n        fullHeight: displayStyle === 'drawer'\n      }\">\n      <div class=\"no-notifications\">\n        <i class=\"fas fa-comment-slash\" [ngStyle]=\"{ color: color ? color : 'blue' }\"></i>\n        <p>No notifications present</p>\n      </div>\n    </div>\n  </div>\n</div>\n\n<div *ngIf=\"displayStyle === 'fullScreen'\">\n  <div class=\"notifications-title\" *ngIf=\"header\">\n    <div class=\"notifications-header\">\n      <h3 class=\"refresh\" [ngStyle]=\"{ marginBottom: '0.4rem' }\">\n        Notifications\n      </h3>\n      <div class=\"btn-group\">\n        <div class=\"tooltip\">\n          <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"saveData()\">\n            <i class=\"fas fa-redo\"></i>\n          </button>\n          <span class=\"tooltiptext\">Refresh</span>\n        </div>\n        <div class=\"tooltip\">\n          <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"markAllRead()\">\n            <i class=\"fas fa-check-double\"></i>\n          </button>\n          <span class=\"tooltiptext\">Mark all as read</span>\n        </div>\n        <button class=\"btn\" (click)=\"toggleModal()\" [ngStyle]=\"{ color: 'rgb(104, 101, 101)', marginLeft: '1rem' }\">\n          <i class=\"fas fa-times\"></i>\n        </button>\n      </div>\n    </div>\n    <p class=\"date\">\n      {{ unread > 0 ? unread : \"No\" }}\n      unread notifications\n    </p>\n  </div>\n  <div class=\"dark-divider\"></div>\n  <div *ngIf=\"!isLoading && notifications.length > 0\" #divToScroll>\n    <div *ngFor=\"let notification of notifications\">\n      <app-notification *ngIf=\"notification\" [notification]=\"notification\" [color]=\"color\"\n        (unreadEmitter)=\"updateUnreadCount($event)\" [onClickNotification]=\"onClickNotification\"></app-notification>\n      <div class=\"divider\"></div>\n    </div>\n    <button [ngStyle]=\"{ color: color ? color : 'blue' }\" *ngIf=\"showLoadButton\" class=\"load-more\" (click)=\"loadMore()\"\n      #loadButton>\n      LOAD MORE\n    </button>\n  </div>\n  <div *ngIf=\"isLoading\" class=\"loading-main bubbleHeight\">\n    <div class=\"loading\" [ngStyle]=\"{ borderTopColor: color ? color : 'blue' }\"></div>\n  </div>\n  <div *ngIf=\"!isLoading && notifications.length === 0\" class=\"loading-main bubbleHeight\">\n    <div class=\"no-notifications\">\n      <i class=\"fas fa-comment-slash\" [ngStyle]=\"{ color: color ? color : 'blue' }\"></i>\n      <p>No notifications present</p>\n    </div>\n  </div>\n</div>", styles: [".wrapper{position:fixed;top:0;left:0;width:100%;height:100%;background:transparent;z-index:100000}button{display:flex;align-items:center;justify-content:center;background:transparent;border:none;cursor:pointer;font-size:1rem}.btn{font-size:1.2rem;margin-left:.3rem;padding:.5rem;height:2rem;width:2rem}.btn:hover{background-color:#f1f1f1;border-radius:1rem}span{cursor:pointer}.tooltip{position:relative;display:inline-block}.tooltiptext{font-size:.8rem}.tooltip .tooltiptext{visibility:hidden;width:100px;background-color:#676464;color:#fff;text-align:center;border-radius:6px;padding:5px 0;position:absolute;z-index:1;top:150%;left:50%;margin-left:-50px}.tooltip .tooltiptext:after{content:\"\";position:absolute;bottom:100%;left:50%;margin-left:-5px;border-width:5px;border-style:solid;border-color:transparent transparent rgb(113,107,107) transparent}.tooltip:hover .tooltiptext{visibility:visible}.notifications{box-shadow:#3c40434d 0 1px 2px,#3c404326 0 2px 6px 2px;background-color:#fff;min-width:300px;width:350px;position:absolute;z-index:100001}.bubble{border:1px solid rgb(235,218,218)}.divider{background-color:#ebdada;height:1px}.dark-divider{background-color:#cbcbcb;height:1px}.btn-group{display:flex;align-items:center}.notifications-header{display:flex;align-items:center;justify-content:space-between}.refresh{display:flex;align-items:center}.refresh span{margin-left:1rem}.mark-read span{margin-right:.5rem}.profile-image{height:50px;width:50px;border-radius:50%;margin-right:1rem}.all-notifications{overflow:scroll}.notification{display:flex;align-items:flex-start;margin-bottom:.3rem;cursor:pointer;padding:.5rem .3rem}.notification:hover{background-color:#add8e6;border-radius:.3rem}.notification span{font-size:.5rem}.footer{margin-top:.8rem}.date{color:#686565;font-size:.85rem}.loading-main{display:flex;align-items:center;justify-content:center}@keyframes spinner{to{transform:rotate(360deg)}}.loading{height:4rem;width:4rem;margin:0 auto;border-radius:50%;border:6px solid #ccc;animation:spinner .6s linear infinite}.load-more{display:block;margin:1rem auto;transition:all linear .3s;padding:.3rem .5rem;font-size:.8rem}.load-more:hover{background-color:#f1f1f1;border-radius:.3rem}.notifications-title{padding:.8rem .8rem .8rem 1.6rem;height:48px;background-color:#fafafa}.no-notifications i{display:flex;flex-direction:column;align-items:center;justify-content:center;color:#00f;font-size:3rem;margin-bottom:2rem;margin-top:-1rem}.bubbleHeight{height:300px}.fullHeight{height:calc(100vh - 71.8px)}.left{margin-top:1rem}.center{margin-top:1rem;margin-left:-165px}.right{margin-top:1rem;margin-left:-320px}.drawerRight{top:0;right:0}.drawerLeft{top:0;left:0}@media (max-width: 480px){.notifications{width:100%}.left,.right,.center{margin-left:0;top:1;left:0}}\n"], dependencies: [{ kind: "directive", type: i2$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: NotificationComponent, selector: "app-notification", inputs: ["notification", "color", "onClickNotification"], outputs: ["unreadEmitter"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-notifications', template: "<div [ngStyle]=\"{\n    fontFamily: fontStyle ? fontStyle : 'inherit',\n    position: displayStyle === 'drawer' ? 'fixed' : 'relative'\n  }\" *ngIf=\"isOpen && displayStyle !== 'fullScreen'\" class=\"wrapper\" (click)=\"onWrapperClick($event)\">\n  <div class=\"notifications\" *ngIf=\"isOpen && displayStyle !== 'fullScreen'\" [ngClass]=\"{\n      bubble: displayStyle === 'bubble',\n      left: displayStyle === 'bubble' && position === 'left',\n      center: displayStyle === 'bubble' && position === 'center',\n      right: displayStyle === 'bubble' && position === 'right',\n      drawerLeft: displayStyle === 'drawer' && position === 'left',\n      drawerRight: displayStyle === 'drawer' && position === 'right'\n    }\">\n    <div class=\"notifications-title\">\n      <div class=\"notifications-header\">\n        <h3 class=\"refresh\" [ngStyle]=\"{ marginBottom: '0.4rem' }\">\n          Notifications\n        </h3>\n        <div class=\"btn-group\">\n          <div class=\"tooltip\">\n            <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"saveData()\">\n              <i class=\"fas fa-redo\"></i>\n            </button>\n            <span class=\"tooltiptext\">Refresh</span>\n          </div>\n          <div class=\"tooltip\">\n            <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"markAllRead()\">\n              <i class=\"fas fa-check-double\"></i>\n            </button>\n            <span class=\"tooltiptext\">Mark all as read</span>\n          </div>\n          <button class=\"btn\" (click)=\"toggleModal()\" [ngStyle]=\"{ color: 'rgb(104, 101, 101)', marginLeft: '1rem' }\">\n            <i class=\"fas fa-times\"></i>\n          </button>\n        </div>\n      </div>\n      <p class=\"date\">\n        {{ unread > 0 ? unread : \"No\" }}\n        unread notifications\n      </p>\n    </div>\n    <div class=\"dark-divider\"></div>\n    <div class=\"all-notifications\" [ngClass]=\"{\n        bubbleHeight: displayStyle === 'bubble',\n        fullHeight: displayStyle === 'drawer'\n      }\" *ngIf=\"!isLoading && notifications.length > 0\" #divToScroll>\n      <div *ngFor=\"let notification of notifications\">\n        <app-notification *ngIf=\"notification\" [notification]=\"notification\" [color]=\"color\"\n          (unreadEmitter)=\"updateUnreadCount($event)\" [onClickNotification]=\"onClickNotification\"></app-notification>\n        <div class=\"divider\"></div>\n      </div>\n      <button [ngStyle]=\"{ color: color ? color : 'blue' }\" *ngIf=\"showLoadButton\" class=\"load-more\"\n        (click)=\"loadMore()\" #loadButton>\n        LOAD MORE\n      </button>\n    </div>\n    <div *ngIf=\"isLoading\" class=\"loading-main\" [ngClass]=\"{\n        bubbleHeight: displayStyle === 'bubble',\n        fullHeight: displayStyle === 'drawer'\n      }\">\n      <div class=\"loading\" [ngStyle]=\"{ borderTopColor: color ? color : 'blue' }\"></div>\n    </div>\n    <div *ngIf=\"!isLoading && notifications.length === 0\" class=\"loading-main\" [ngClass]=\"{\n        bubbleHeight: displayStyle === 'bubble',\n        fullHeight: displayStyle === 'drawer'\n      }\">\n      <div class=\"no-notifications\">\n        <i class=\"fas fa-comment-slash\" [ngStyle]=\"{ color: color ? color : 'blue' }\"></i>\n        <p>No notifications present</p>\n      </div>\n    </div>\n  </div>\n</div>\n\n<div *ngIf=\"displayStyle === 'fullScreen'\">\n  <div class=\"notifications-title\" *ngIf=\"header\">\n    <div class=\"notifications-header\">\n      <h3 class=\"refresh\" [ngStyle]=\"{ marginBottom: '0.4rem' }\">\n        Notifications\n      </h3>\n      <div class=\"btn-group\">\n        <div class=\"tooltip\">\n          <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"saveData()\">\n            <i class=\"fas fa-redo\"></i>\n          </button>\n          <span class=\"tooltiptext\">Refresh</span>\n        </div>\n        <div class=\"tooltip\">\n          <button class=\"btn\" [ngStyle]=\"{ color: color ? color : 'blue' }\" (click)=\"markAllRead()\">\n            <i class=\"fas fa-check-double\"></i>\n          </button>\n          <span class=\"tooltiptext\">Mark all as read</span>\n        </div>\n        <button class=\"btn\" (click)=\"toggleModal()\" [ngStyle]=\"{ color: 'rgb(104, 101, 101)', marginLeft: '1rem' }\">\n          <i class=\"fas fa-times\"></i>\n        </button>\n      </div>\n    </div>\n    <p class=\"date\">\n      {{ unread > 0 ? unread : \"No\" }}\n      unread notifications\n    </p>\n  </div>\n  <div class=\"dark-divider\"></div>\n  <div *ngIf=\"!isLoading && notifications.length > 0\" #divToScroll>\n    <div *ngFor=\"let notification of notifications\">\n      <app-notification *ngIf=\"notification\" [notification]=\"notification\" [color]=\"color\"\n        (unreadEmitter)=\"updateUnreadCount($event)\" [onClickNotification]=\"onClickNotification\"></app-notification>\n      <div class=\"divider\"></div>\n    </div>\n    <button [ngStyle]=\"{ color: color ? color : 'blue' }\" *ngIf=\"showLoadButton\" class=\"load-more\" (click)=\"loadMore()\"\n      #loadButton>\n      LOAD MORE\n    </button>\n  </div>\n  <div *ngIf=\"isLoading\" class=\"loading-main bubbleHeight\">\n    <div class=\"loading\" [ngStyle]=\"{ borderTopColor: color ? color : 'blue' }\"></div>\n  </div>\n  <div *ngIf=\"!isLoading && notifications.length === 0\" class=\"loading-main bubbleHeight\">\n    <div class=\"no-notifications\">\n      <i class=\"fas fa-comment-slash\" [ngStyle]=\"{ color: color ? color : 'blue' }\"></i>\n      <p>No notifications present</p>\n    </div>\n  </div>\n</div>", styles: [".wrapper{position:fixed;top:0;left:0;width:100%;height:100%;background:transparent;z-index:100000}button{display:flex;align-items:center;justify-content:center;background:transparent;border:none;cursor:pointer;font-size:1rem}.btn{font-size:1.2rem;margin-left:.3rem;padding:.5rem;height:2rem;width:2rem}.btn:hover{background-color:#f1f1f1;border-radius:1rem}span{cursor:pointer}.tooltip{position:relative;display:inline-block}.tooltiptext{font-size:.8rem}.tooltip .tooltiptext{visibility:hidden;width:100px;background-color:#676464;color:#fff;text-align:center;border-radius:6px;padding:5px 0;position:absolute;z-index:1;top:150%;left:50%;margin-left:-50px}.tooltip .tooltiptext:after{content:\"\";position:absolute;bottom:100%;left:50%;margin-left:-5px;border-width:5px;border-style:solid;border-color:transparent transparent rgb(113,107,107) transparent}.tooltip:hover .tooltiptext{visibility:visible}.notifications{box-shadow:#3c40434d 0 1px 2px,#3c404326 0 2px 6px 2px;background-color:#fff;min-width:300px;width:350px;position:absolute;z-index:100001}.bubble{border:1px solid rgb(235,218,218)}.divider{background-color:#ebdada;height:1px}.dark-divider{background-color:#cbcbcb;height:1px}.btn-group{display:flex;align-items:center}.notifications-header{display:flex;align-items:center;justify-content:space-between}.refresh{display:flex;align-items:center}.refresh span{margin-left:1rem}.mark-read span{margin-right:.5rem}.profile-image{height:50px;width:50px;border-radius:50%;margin-right:1rem}.all-notifications{overflow:scroll}.notification{display:flex;align-items:flex-start;margin-bottom:.3rem;cursor:pointer;padding:.5rem .3rem}.notification:hover{background-color:#add8e6;border-radius:.3rem}.notification span{font-size:.5rem}.footer{margin-top:.8rem}.date{color:#686565;font-size:.85rem}.loading-main{display:flex;align-items:center;justify-content:center}@keyframes spinner{to{transform:rotate(360deg)}}.loading{height:4rem;width:4rem;margin:0 auto;border-radius:50%;border:6px solid #ccc;animation:spinner .6s linear infinite}.load-more{display:block;margin:1rem auto;transition:all linear .3s;padding:.3rem .5rem;font-size:.8rem}.load-more:hover{background-color:#f1f1f1;border-radius:.3rem}.notifications-title{padding:.8rem .8rem .8rem 1.6rem;height:48px;background-color:#fafafa}.no-notifications i{display:flex;flex-direction:column;align-items:center;justify-content:center;color:#00f;font-size:3rem;margin-bottom:2rem;margin-top:-1rem}.bubbleHeight{height:300px}.fullHeight{height:calc(100vh - 71.8px)}.left{margin-top:1rem}.center{margin-top:1rem;margin-left:-165px}.right{margin-top:1rem;margin-left:-320px}.drawerRight{top:0;right:0}.drawerLeft{top:0;left:0}@media (max-width: 480px){.notifications{width:100%}.left,.right,.center{margin-left:0;top:1;left:0}}\n"] }]
        }], ctorParameters: function () { return [{ type: NotificationService }]; }, propDecorators: { color: [{
                type: Input
            }], indicatorType: [{
                type: Input
            }], fontStyle: [{
                type: Input
            }], onClickNotification: [{
                type: Input
            }], displayStyle: [{
                type: Input
            }], position: [{
                type: Input
            }], header: [{
                type: Input
            }] } });

class RavenInAppComponent {
    constructor() {
        this.color = 'blue';
        this.indicatorType = 'count';
        this.displayStyle = 'bubble';
        this.position = 'left';
        this.header = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RavenInAppComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: RavenInAppComponent, selector: "inapp-notification-center", inputs: { color: "color", indicatorType: "indicatorType", fontStyle: "fontStyle", onClickNotification: "onClickNotification", displayStyle: "displayStyle", position: "position", header: "header" }, ngImport: i0, template: "<div>\n\n  <head>\n    <base href=\"/\" />\n    <link rel=\"stylesheet\" href=\"https://use.fontawesome.com/releases/v6.1.1/css/all.css\" />\n  </head>\n  <div class=\"main\">\n    <app-bell-icon [color]=\"color\" [indicatorType]=\"indicatorType\"\n      *ngIf=\"displayStyle !== 'fullScreen'\"></app-bell-icon>\n    <app-notifications [color]=\"color\" [indicatorType]=\"indicatorType\" [fontStyle]=\"fontStyle\"\n      [onClickNotification]=\"onClickNotification\" [displayStyle]=\"displayStyle\" [position]=\"position\"\n      [header]=\"header\"></app-notifications>\n  </div>\n</div>", styles: ["body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",Segoe UI Symbol;margin:0}h1,h2,h3,h4,h5,h6,p{margin:0}a{text-decoration:none}\n"], dependencies: [{ kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: BellIconComponent, selector: "app-bell-icon", inputs: ["color", "indicatorType"] }, { kind: "component", type: NotificationsComponent, selector: "app-notifications", inputs: ["color", "indicatorType", "fontStyle", "onClickNotification", "displayStyle", "position", "header"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RavenInAppComponent, decorators: [{
            type: Component,
            args: [{ selector: 'inapp-notification-center', encapsulation: ViewEncapsulation.None, template: "<div>\n\n  <head>\n    <base href=\"/\" />\n    <link rel=\"stylesheet\" href=\"https://use.fontawesome.com/releases/v6.1.1/css/all.css\" />\n  </head>\n  <div class=\"main\">\n    <app-bell-icon [color]=\"color\" [indicatorType]=\"indicatorType\"\n      *ngIf=\"displayStyle !== 'fullScreen'\"></app-bell-icon>\n    <app-notifications [color]=\"color\" [indicatorType]=\"indicatorType\" [fontStyle]=\"fontStyle\"\n      [onClickNotification]=\"onClickNotification\" [displayStyle]=\"displayStyle\" [position]=\"position\"\n      [header]=\"header\"></app-notifications>\n  </div>\n</div>", styles: ["body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",Segoe UI Symbol;margin:0}h1,h2,h3,h4,h5,h6,p{margin:0}a{text-decoration:none}\n"] }]
        }], propDecorators: { color: [{
                type: Input
            }], indicatorType: [{
                type: Input
            }], fontStyle: [{
                type: Input
            }], onClickNotification: [{
                type: Input
            }], displayStyle: [{
                type: Input
            }], position: [{
                type: Input
            }], header: [{
                type: Input
            }] } });

class RavenInAppModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RavenInAppModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: RavenInAppModule, declarations: [RavenInAppComponent,
            BellIconComponent,
            NotificationsComponent,
            NotificationComponent], imports: [CommonModule, HttpClientModule], exports: [RavenInAppComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RavenInAppModule, imports: [CommonModule, HttpClientModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RavenInAppModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        RavenInAppComponent,
                        BellIconComponent,
                        NotificationsComponent,
                        NotificationComponent,
                    ],
                    imports: [CommonModule, HttpClientModule],
                    exports: [RavenInAppComponent],
                }]
        }] });

class CountService {
    constructor(notificationService) {
        this.notificationService = notificationService;
        this.count = this.notificationService.currentCount;
        this.unreadCount = this.notificationService.currentUnread;
    }
    // tslint:disable: typedef
    intialize(appId, userId, signature) {
        this.notificationService.intialize(appId, userId, signature);
    }
    markAllRead() {
        this.notificationService.markAllRead();
    }
    reloadData() {
        this.notificationService.reloadData();
    }
    deintialize() {
        this.notificationService.deintialize();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CountService, deps: [{ token: NotificationService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CountService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CountService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: NotificationService }]; } });

/*
 * Public API Surface of in-app
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CountService, RavenInAppComponent, RavenInAppModule };
//# sourceMappingURL=ravenapp-raven-inapp-angular.mjs.map
